@@ -76,7 +76,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "5.1.1"
+__version__ = "5.2.1"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Logger.git"
 
 # pylint:disable=undefined-all-variable
@@ -187,6 +187,8 @@ class StreamHandler(Handler):
         with string inputs
     """
 
+    terminator = "\n"
+
     def __init__(self, stream: Optional[WriteableStream] = None) -> None:
         super().__init__()
         if stream is None:
@@ -199,7 +201,7 @@ class StreamHandler(Handler):
 
         :param record: The record (message object) to be logged
         """
-        self.stream.write(self.format(record) + "\n")
+        self.stream.write(self.format(record) + self.terminator)
 
 
 class FileHandler(StreamHandler):
@@ -370,7 +372,7 @@ class Logger:
     def debug(self, msg: str, *args) -> None:
         """Log a debug message.
 
-        :param str fmsg: the core message string with embedded
+        :param str msg: the core message string with embedded
             formatting directives
         :param args: arguments to ``msg % args``;
             can be empty
